@@ -37,7 +37,9 @@ class Exec:
                 input_ele = one.pop('input')
                 step,step_text = list(one.items())[0]
                 with allure.step(f'步骤{step}:{step_text}'):
-                    self.driver.find_element(*input_ele[:-1]).send_keys(input_ele[-1])
+                    ele =self.driver.find_element(*input_ele[:-1])
+                    ele.clear()
+                    ele.send_keys(input_ele[-1])
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={input_ele[:-1][0]},定位的值{input_ele[:-1][-1]}')
                     log.info(f'输入的值{input_ele[-1]}')
